@@ -32,6 +32,9 @@ FAILEDOPERATION_BALANCEINSUFFICIENT = 'FailedOperation.BalanceInsufficient'
 # 创建云联网失败. 请重试你的请求，如果问题仍然存在，请联系腾讯云客服。
 FAILEDOPERATION_CREATECCNFAILED = 'FailedOperation.CreateCcnFailed'
 
+# 创建VPN网关失败,请重试你的请求，如果问题仍然存在，请联系腾讯云客服。
+FAILEDOPERATION_CREATEVPNGATEWAYFAILED = 'FailedOperation.CreateVpnGatewayFailed'
+
 # 不支持的地域。
 FAILEDOPERATION_INVALIDREGION = 'FailedOperation.InvalidRegion'
 
@@ -140,6 +143,12 @@ INVALIDPARAMETERCONFLICT = 'InvalidParameterConflict'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 接入网段掩码必须在12-28之间。
+INVALIDPARAMETERVALUE_ACCESSSUBNETMASK = 'InvalidParameterValue.AccessSubnetMask'
+
+# 接入网段前缀必须是10，172，192开头。
+INVALIDPARAMETERVALUE_ACCESSSUBNETPREFIX = 'InvalidParameterValue.AccessSubnetPrefix'
+
 # 被攻击的IP地址。
 INVALIDPARAMETERVALUE_ADDRESSATTACKED = 'InvalidParameterValue.AddressAttacked'
 
@@ -224,6 +233,9 @@ INVALIDPARAMETERVALUE_DUPLICATEDLBTRAFFICMIRRORRECIVERENDPOINT = 'InvalidParamet
 # 值超过上限。
 INVALIDPARAMETERVALUE_EIPBRANDWIDTHOUTINVALID = 'InvalidParameterValue.EIPBrandWidthOutInvalid'
 
+# 出口不一致
+INVALIDPARAMETERVALUE_EGRESSCONFLICT = 'InvalidParameterValue.EgressConflict'
+
 # 缺少参数。
 INVALIDPARAMETERVALUE_EMPTY = 'InvalidParameterValue.Empty'
 
@@ -278,6 +290,9 @@ INVALIDPARAMETERVALUE_INVALIDBUSINESS = 'InvalidParameterValue.InvalidBusiness'
 # 传入的DedicatedClusterId有误。
 INVALIDPARAMETERVALUE_INVALIDDEDICATEDCLUSTERID = 'InvalidParameterValue.InvalidDedicatedClusterId'
 
+# egress的值无效。
+INVALIDPARAMETERVALUE_INVALIDEGRESS = 'InvalidParameterValue.InvalidEgress'
+
 # 该IP只能绑定小时流量后付费和带宽包实例。
 INVALIDPARAMETERVALUE_INVALIDINSTANCEINTERNETCHARGETYPE = 'InvalidParameterValue.InvalidInstanceInternetChargeType'
 
@@ -503,6 +518,9 @@ INVALIDPARAMETERVALUE_TRAFFICPACKAGERESOURCEIDMALFORMED = 'InvalidParameterValue
 # 该可用区不可用。
 INVALIDPARAMETERVALUE_UNAVAILABLEZONE = 'InvalidParameterValue.UnavailableZone'
 
+# 账号不支持该egress
+INVALIDPARAMETERVALUE_UNSUPPORTEDEGRESS = 'InvalidParameterValue.UnsupportedEgress'
+
 # 当前公网IP所在的地区不支持流量采集。
 INVALIDPARAMETERVALUE_UNSUPPORTEDLBTRAFFICMIRRORAZ = 'InvalidParameterValue.UnsupportedLbTrafficMirrorAz'
 
@@ -710,6 +728,9 @@ RESOURCEINUSE = 'ResourceInUse'
 # 指定IP地址已经在使用中。
 RESOURCEINUSE_ADDRESS = 'ResourceInUse.Address'
 
+# 当前NAT实例已关联云防火墙，不可删除。
+RESOURCEINUSE_NATUSEDBYCFW = 'ResourceInUse.NatUsedByCFW'
+
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
@@ -806,9 +827,15 @@ UNSUPPORTEDOPERATION_BANDWIDTHNOTEXPIRED = 'UnsupportedOperation.BandwidthNotExp
 # 该带宽包不支持此操作。
 UNSUPPORTEDOPERATION_BANDWIDTHPACKAGEIDNOTSUPPORTED = 'UnsupportedOperation.BandwidthPackageIdNotSupported'
 
+# 绑定了防火墙，请先到防火墙页面解绑。
+UNSUPPORTEDOPERATION_BINDCLOUDFIREWALL = 'UnsupportedOperation.BindCloudFirewall'
+
 # 已绑定EIP。
 UNSUPPORTEDOPERATION_BINDEIP = 'UnsupportedOperation.BindEIP'
 
+# 资源在BPAAS审批中。
+UNSUPPORTEDOPERATION_BPAASRESOURCES = 'UnsupportedOperation.BpaasResources'
+
 # 添加 community 时，传播条件只支持 vpg 类型或 vpg 实例
 UNSUPPORTEDOPERATION_BROADCASTCONDITIONMUSTBEVPGTYPEORVPGINSTANCE = 'UnsupportedOperation.BroadcastConditionMustBeVpgTypeOrVpgInstance'
 
@@ -857,6 +884,9 @@ UNSUPPORTEDOPERATION_CCNROUTETABLENOTEXIST = 'UnsupportedOperation.CcnRouteTable
 # 流量计量类型云联网暂不支持跨境
 UNSUPPORTEDOPERATION_CCNTRAFFICMETERINGUNABLECROSSBORDER = 'UnsupportedOperation.CcnTrafficMeteringUnableCrossBorder'
 
+# 配置Cdc子网发布前需要先设置VPC属性CdcId。
+UNSUPPORTEDOPERATION_CDCPUBLISHNEEDCDCID = 'UnsupportedOperation.CdcPublishNeedCdcId'
+
 # CDC子网不支持创建非本地网关类型的路由。
 UNSUPPORTEDOPERATION_CDCSUBNETNOTSUPPORTUNLOCALGATEWAY = 'UnsupportedOperation.CdcSubnetNotSupportUnLocalGateway'
 
@@ -935,6 +965,9 @@ UNSUPPORTEDOPERATION_ECMPWITHUSERROUTE = 'UnsupportedOperation.EcmpWithUserRoute
 # 当前地域不支持启用组播。
 UNSUPPORTEDOPERATION_ENABLEMULTICAST = 'UnsupportedOperation.EnableMulticast'
 
+# 终端节点需要先解绑 GWLB EIP。
+UNSUPPORTEDOPERATION_ENDPOINTHADGWLBEIPUNASSOCIATE = 'UnsupportedOperation.EndPointHadGwlbEipUnassociate'
+
 # 终端节点和终端节点服务的CdcId不一致。
 UNSUPPORTEDOPERATION_ENDPOINTMISMATCHENDPOINTSERVICECDCID = 'UnsupportedOperation.EndPointMismatchEndPointServiceCdcId'
 
@@ -959,6 +992,9 @@ UNSUPPORTEDOPERATION_FLOWLOGSNOTSUPPORTKOINSTANCEENI = 'UnsupportedOperation.Flo
 # 不支持创建流日志：当前弹性网卡未绑定实例。
 UNSUPPORTEDOPERATION_FLOWLOGSNOTSUPPORTNULLINSTANCEENI = 'UnsupportedOperation.FlowLogsNotSupportNullInstanceEni'
 
+# GUA类型的网段不支持分配给CDC子网。
+UNSUPPORTEDOPERATION_GUANOTSUPPORTALLOCATECDCSUBNET = 'UnsupportedOperation.GUANotSupportAllocateCdcSubnet'
+
 # TGW还没有投放IPv6网段
 UNSUPPORTEDOPERATION_IPV6CIDRNOTDEPLOYED = 'UnsupportedOperation.IPV6CidrNotDeployed'
 
@@ -974,6 +1010,9 @@ UNSUPPORTEDOPERATION_INCORRECTADDRESSRESOURCETYPE = 'UnsupportedOperation.Incorr
 # 用户配置的实例和路由表不匹配。
 UNSUPPORTEDOPERATION_INSTANCEANDRTBNOTMATCH = 'UnsupportedOperation.InstanceAndRtbNotMatch'
 
+# 实例在Havip漂移范围内，需要先解绑定关联。
+UNSUPPORTEDOPERATION_INSTANCEASSOCIATEHAVIP = 'UnsupportedOperation.InstanceAssociateHavip'
+
 # 当前云联网`%(value)s`的CdcId与传入实例的CdcId不一致，不支持关联。
 UNSUPPORTEDOPERATION_INSTANCECDCIDNOTMATCHCCNCDCID = 'UnsupportedOperation.InstanceCdcIdNotMatchCcnCdcId'
 
@@ -1070,6 +1109,9 @@ UNSUPPORTEDOPERATION_NATGATEWAYTYPENOTSUPPORTSNAT = 'UnsupportedOperation.NatGat
 # NAT实例不支持该操作。
 UNSUPPORTEDOPERATION_NATNOTSUPPORTED = 'UnsupportedOperation.NatNotSupported'
 
+# 没有CDC专线网关。
+UNSUPPORTEDOPERATION_NOCDCDCGW = 'UnsupportedOperation.NoCdcDcGw'
+
 # 指定的子网不支持创建本地网关类型的路由。
 UNSUPPORTEDOPERATION_NORMALSUBNETNOTSUPPORTLOCALGATEWAY = 'UnsupportedOperation.NormalSubnetNotSupportLocalGateway'
 
@@ -1091,6 +1133,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTATTACHEDGEANDCROSSBORDERINSTANCE = 'UnsupportedOp
 # 没有开启多路由表特性，不能创建用户路由表。
 UNSUPPORTEDOPERATION_NOTSUPPORTCREATECCNROUTETABLE = 'UnsupportedOperation.NotSupportCreateCcnRouteTable'
 
+# 当前操作不支持创建Ipv6类型VPN网关。
+UNSUPPORTEDOPERATION_NOTSUPPORTCREATEIPV6VPNGATEWAY = 'UnsupportedOperation.NotSupportCreateIpv6VpnGateway'
+
 # 默认路由表，不支持删除。
 UNSUPPORTEDOPERATION_NOTSUPPORTDELETEDEFAULTCCNROUTETABLE = 'UnsupportedOperation.NotSupportDeleteDefaultCcnRouteTable'
 
@@ -1115,6 +1160,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTEDADDRESSIPSCHARGETYPE = 'UnsupportedOperation.No
 # 不支持创建后付费流量计费类型云联网
 UNSUPPORTEDOPERATION_NOTSUPPORTEDCREATETRAFFICMETERINGTYPECCN = 'UnsupportedOperation.NotSupportedCreateTrafficMeteringTypeCcn'
 
+# 当前VPN网关不支持指定客户端网段类型
+UNSUPPORTEDOPERATION_NOTSUPPORTEDLOCALADDRESSTYPE = 'UnsupportedOperation.NotSupportedLocalAddressType'
+
 # 此地域没有上线出口二资源，请到北京/广州/南京购买。
 UNSUPPORTEDOPERATION_NOTSUPPORTEDPURCHASECENTEREGRESSRESOURCE = 'UnsupportedOperation.NotSupportedPurchaseCenterEgressResource'
 
@@ -1139,9 +1187,18 @@ UNSUPPORTEDOPERATION_PREPAIDCCNONLYSUPPORTINTERREGIONLIMIT = 'UnsupportedOperati
 # 指定的值是主IP。
 UNSUPPORTEDOPERATION_PRIMARYIP = 'UnsupportedOperation.PrimaryIp'
 
+# 不支持创建私网BGP类型VPN网关。
+UNSUPPORTEDOPERATION_PRIVATEBGPVPNGATEWAY = 'UnsupportedOperation.PrivateBgpVpnGateway'
+
 # 私网NAT网关存在关联规则。
 UNSUPPORTEDOPERATION_PRIVATENATGATEWAYASSOCIATIONEXISTS = 'UnsupportedOperation.PrivateNatGatewayAssociationExists'
 
+# 不支持创建私网Ssl类型VPN网关。
+UNSUPPORTEDOPERATION_PRIVATESSLVPNGATEWAY = 'UnsupportedOperation.PrivateSslVpnGateway'
+
+# 不支持创建私网类型VPN网关。
+UNSUPPORTEDOPERATION_PRIVATEVPNGATEWAY = 'UnsupportedOperation.PrivateVpnGateway'
+
 # 不支持公网CLB。
 UNSUPPORTEDOPERATION_PUBLICCLBNOTSUPPORT = 'UnsupportedOperation.PublicClbNotSupport'
 
@@ -1178,6 +1235,9 @@ UNSUPPORTEDOPERATION_RESOURCEMISMATCH = 'UnsupportedOperation.ResourceMismatch'
 # 未找到相关角色，请确认角色是否授权。
 UNSUPPORTEDOPERATION_ROLENOTFOUND = 'UnsupportedOperation.RoleNotFound'
 
+# 只支持自研VPC创建或修改PVGW2类型路由。
+UNSUPPORTEDOPERATION_ROUTEPVGW2 = 'UnsupportedOperation.RoutePvgw2'
+
 # 当前路由表删除失败，请先检查是否存在关联的策略。
 UNSUPPORTEDOPERATION_ROUTETABLECANNOTDELETE = 'UnsupportedOperation.RouteTableCanNotDelete'
 
@@ -1199,6 +1259,9 @@ UNSUPPORTEDOPERATION_SSLCLIENTCERTALREADYENABLEORCERTABNORMAL = 'UnsupportedOper
 # SSL客户端状态不可用，不支持下载
 UNSUPPORTEDOPERATION_SSLCLIENTCERTDISABLEUNSUPPORTEDDOWNLOADSSLCLIENTCERT = 'UnsupportedOperation.SSLClientCertDisableUnsupportedDownloadSSLClientCert'
 
+# 安全组展开后的规则已达到上限。
+UNSUPPORTEDOPERATION_SGNUMEXCEEDLIMIT = 'UnsupportedOperation.SgNumExceedLimit'
+
 # 实例已关联快照策略。
 UNSUPPORTEDOPERATION_SNAPSHOTATTACHED = 'UnsupportedOperation.SnapshotAttached'
 
@@ -1232,6 +1295,9 @@ UNSUPPORTEDOPERATION_SSLVPNCLIENTIDNOTFOUND = 'UnsupportedOperation.SslVpnClient
 # 中继网卡不支持该操作。
 UNSUPPORTEDOPERATION_SUBENINOTSUPPORTTRUNKING = 'UnsupportedOperation.SubEniNotSupportTrunking'
 
+# 子网与Vpc配置的CdcId不一致。
+UNSUPPORTEDOPERATION_SUBNETMISMATCHVPCCDCID = 'UnsupportedOperation.SubnetMismatchVpcCdcId'
+
 # 子网不存在。
 UNSUPPORTEDOPERATION_SUBNETNOTEXISTS = 'UnsupportedOperation.SubnetNotExists'
 
